@@ -3,6 +3,7 @@
 // Use is subject to license terms.
 //
 
+use std::collections::HashMap;
 use std::fmt;
 
 use dialoguer::{theme, Confirm};
@@ -294,7 +295,7 @@ enum Command {
     )]
     ListPods,
 
-    #[structopt(about = "List K8s node regions", display_order(1000))]
+    #[structopt(about = "List K8s node regions", aliases = &["list-r", "lr"], display_order(1000))]
     ListRegions {
         #[structopt(help = "Also list zones", long, short)]
         zone: bool,
@@ -683,12 +684,6 @@ impl StateHub {
         output.into_text(self.json)
     }
 
-    async fn list_regions(&self, zone: bool) -> anyhow::Result<()> {
-        k8s::get_regions(zone)
-            .await
-            .map(|nodes| println!("{}", nodes.show()))
-    }
-
     async fn create_namespace(&self, namespace: String) -> anyhow::Result<()> {
         k8s::validate_namespace(namespace)
             .await
@@ -716,6 +711,18 @@ impl StateHub {
         Ok(())
     }
 
+    async fn list_regions(&self, zone: bool) -> anyhow::Result<()> {
+        k8s::get_regions(zone)
+            .await
+            .map(|map| {
+                map.into_iter()
+                    .map(|(key, value)| (key.unwrap_or_default(), value))
+                    .collect::<HashMap<_, _>>()
+            })
+            .map(Output::from)
+            .handle_output(self.json)
+    }
+
     async fn list_namespaces(&self) -> anyhow::Result<()> {
         k8s::list_namespaces()
             .await?
